package swingschooljdbc.gui.tablemodels;

import java.sql.SQLException;
import java.util.Collections;
import java.util.Date;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.table.AbstractTableModel;
import swingschooljdbc.gui.SwingSchoolFrame;
import swingschooljdbc.logic.DataSource;
import swingschooljdbc.logic.entities.Mark;

public class MarkTableModel extends AbstractTableModel {

    @Override
    public int getRowCount() {
        try {
            return DataSource.getInstance().getMarkController().getMarkCount();
        } catch (SQLException ex) {
            SwingSchoolFrame.showError(ex.getMessage());
            return 0;
        }
    }

    @Override
    public int getColumnCount() {
        return Mark.fieldNames.length;
    }

    @Override
    public Object getValueAt(int rowIndex, int columnIndex) {
        Mark mark;
        try {
            mark = DataSource.getInstance().getMarkController().getMark(rowIndex);
        } catch (SQLException ex) {
            SwingSchoolFrame.showError(ex.getMessage());
            return "?";
        }
        switch (columnIndex) {
            case 0:
                return mark.getStudent().getFirstName() + " " + mark.getStudent().getLastName();
            case 1:
                return mark.getSubject().getTitle();
            case 2:
                return mark.getDate();
            case 3:
                return mark.getMark();
            default:
                return null;
        }
    }

    @Override
    public Class<?> getColumnClass(int columnIndex) {
        switch (columnIndex) {
            case 0:
            case 1:
                return String.class;
            case 2:
                return Date.class;
            case 3:
                return Integer.class;
            default:
                return null;
        }
    }

    @Override
    public String getColumnName(int column) {
        return Mark.fieldNames[column];
    }

    public void addMark() {
        try {
            DataSource.getInstance().getMarkController().addMark();
        } catch (SQLException ex) {
            SwingSchoolFrame.showError(ex.getMessage());
        }
        int row = getRowCount() - 1;
        fireTableRowsInserted(row, row);
    }

    public void deleteMarks(List<Integer> selectedModelIndices) {
        Collections.sort(selectedModelIndices);
        Collections.reverse(selectedModelIndices);
        try {
            DataSource.getInstance().getMarkController().deleteMarks(selectedModelIndices);
        } catch (SQLException ex) {
            SwingSchoolFrame.showError(ex.getMessage());
        }
        fireTableDataChanged();
    }
}
