package swingschooljdbc.logic.controllers;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.sql.Timestamp;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.List;
import javax.swing.text.DateFormatter;
import swingschooljdbc.logic.DataSource;
import swingschooljdbc.logic.entities.Mark;

public class MarkController {

    public int getMarkCount() throws SQLException {
        int markCount;
        try (
                Connection connection = DataSource.getInstance().getConnection();
                Statement statement = connection.createStatement();
                ResultSet resultSet = statement.executeQuery("SELECT COUNT(*) AS CNT FROM MARK");) {
            resultSet.next();
            markCount = resultSet.getInt("CNT");
        }
        return markCount;
    }

    public Mark getMark(int rowIndex) throws SQLException {
        Mark mark = new Mark();
        int studentId, subjectId;
        try (
                Connection connection = DataSource.getInstance().getConnection();
                Statement statement = connection.createStatement(ResultSet.TYPE_SCROLL_INSENSITIVE, ResultSet.CONCUR_READ_ONLY);
                ResultSet resultSet = statement.executeQuery("SELECT * FROM MARK");) {
            resultSet.absolute(rowIndex + 1);
            mark.setMarkId(resultSet.getInt(1));
            studentId = resultSet.getInt(2);
            subjectId = resultSet.getInt(3);
            mark.setDate(resultSet.getDate(4));
            mark.setMark(resultSet.getInt(5));
        }
        mark.setSubject(DataSource.getInstance().getSubjectController().getSubjectById(subjectId));
        mark.setStudent(DataSource.getInstance().getStudentController().getStudentById(studentId));
        return mark;
    }

    public void addMark() throws SQLException {
        int newId = DataSource.getInstance().obtainNewId();
        int studentId = DataSource.getInstance().getStudentController().getStudent(0).getStudentId();
        int subjectId = DataSource.getInstance().getSubjectController().getSubject(0).getSubjectId();
        Calendar c = Calendar.getInstance();
        Timestamp timestamp = new Timestamp(c.getTimeInMillis());
        int mark = 5;
        try (
                Connection connection = DataSource.getInstance().getConnection();
                PreparedStatement prepareStatement = connection.prepareStatement("INSERT INTO MARK VALUES (?, ?, ?, ?, ?)");) {
            prepareStatement.setInt(1, newId);
            prepareStatement.setInt(2, studentId);
            prepareStatement.setInt(3, subjectId);
            prepareStatement.setTimestamp(4, timestamp);
            prepareStatement.setInt(5, mark);
            prepareStatement.execute();
        }
    }

    public void deleteMarks(List<Integer> selectedModelIndices) throws SQLException {
        try (
                Connection connection = DataSource.getInstance().getConnection();
                Statement statement = connection.createStatement(ResultSet.TYPE_SCROLL_INSENSITIVE, ResultSet.CONCUR_UPDATABLE);
                ResultSet resultSet = statement.executeQuery("SELECT * FROM MARK");) {
            for (Integer rowIndex : selectedModelIndices) {
                resultSet.absolute(rowIndex + 1);
                resultSet.deleteRow();
            }
        }
    }
}
